@@ -1,7 +1,7 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: validate_gpkg.py ba2bc11ffb14b86b216b2884f3dfad3a45abe2b4 2021-04-25 23:25:47 +0200 Even Rouault $
+# $Id: validate_gpkg.py b8c5210d966c40d420031013ffc2a39de55ba330 2021-05-06 23:47:09 +0200 Even Rouault $
 #
 # Project:  GDAL/OGR
 # Purpose:  Test compliance of GeoPackage database w.r.t GeoPackage spec
@@ -187,6 +187,14 @@ class GPKGChecker(object):
                 "as gpkg_spatial_ref_sys has a definition_12_063 column")
 
         if has_definition_12_063:
+
+            has_epoch_column = False
+            try:
+                c.execute("SELECT epoch FROM gpkg_spatial_ref_sys")
+                has_epoch_column = True
+            except:
+                pass
+
             expected_columns = [
                 (0, 'srs_name', 'TEXT', 1, None, 0),
                 (1, 'srs_id', 'INTEGER', 1, None, 1),
@@ -196,6 +204,8 @@ class GPKGChecker(object):
                 (5, 'description', 'TEXT', 0, None, 0),
                 (6, 'definition_12_063', 'TEXT', 1, None, 0)
             ]
+            if has_epoch_column:
+                expected_columns += [(7, 'epoch', 'DOUBLE', 0, None, 0)]
         else:
             expected_columns = [
                 (0, 'srs_name', 'TEXT', 1, None, 0),
